cbc: COIN-OR branch and cut solver for mixed-integer programs
=============================================================

Description
-----------

The Computational Infrastructure for Operations Research (COIN-OR**, or
simply COIN) project is an initiative to spur the development of
open-source software for the operations research community.

The COIN Branch and Cut solver (CBC) is an open-source mixed-integer
program (MIP) solver written in C++. CBC is intended to be used
primarily as a callable library to create customized branch-and-cut
solvers. A basic, stand-alone executable version is also available. CBC
is an active open-source project led by John Forrest at www.coin-or.org.

License
-------

Eclipse Public License, Version 1.0 (EPL-1.0)
(http://opensource.org/licenses/eclipse-1.0)


Upstream Contact
----------------

-  John Forrest <jjforre@us.ibm.com>
-  Robin Lougee-Heimer


Project Home Page
-----------------

-  https://projects.coin-or.org/Cbc
